/*
 * menu_selections.hpp
 *
 * Copyright (c) Stephen Thompson, 2007.
 * Licenced for non-commercial use only. See LICENCE.txt for details.
 *
 */

#ifndef MENU_SELECTIONS_HPP
#define MENU_SELECTIONS_HPP

#include "misc/exception_base.hpp"

#include <map>
using namespace std;

class MenuItem;
class MenuValue;

class MenuItemNotFound : public ExceptionBase {
public:
	explicit MenuItemNotFound(const string &offending_item_id)
		: ExceptionBase(string("menu item ") + offending_item_id + string(" not found")) { }
};

class MenuSelections {
public:
	void set(const string &item_id, int value) { m[item_id] = value; }
	int get(const string &item_id) const {
		map<string,int>::const_iterator it = m.find(item_id);
		if (it == m.end()) throw MenuItemNotFound(item_id);
		else return it->second;
	}
private:
	map<string, int> m;
};

class MenuInt {
public:
	virtual ~MenuInt() { }
	virtual int getValue(const MenuSelections &) const = 0;
};

class MenuIntConst : public MenuInt {
public:
	explicit MenuIntConst(int xx) : x(xx) { }
	virtual int getValue(const MenuSelections &) const { return x; }
private:
	int x;
};

class MenuIntVar : public MenuInt {
public:
	explicit MenuIntVar(const string &i) : item_id(i) { }
	virtual int getValue(const MenuSelections &ms) const { return ms.get(item_id); }
private:
	string item_id;
};

#endif
