/*
 * stylus_controller.hpp
 *
 * Copyright (c) Stephen Thompson, 2007.
 * Licenced for non-commercial use only. See LICENCE.txt for details.
 *
 * Intended for use with PocketPC.
 *
 * If the mouse is clicked, then controller returns UP, DOWN, LEFT or RIGHT
 * depending on where the mouse pointer is located (wrt the knight). If mouse is
 * not clicked then controller is left centred.
 *
 * Fire-button is still done as a keypress, as before.
 *
 */

#ifndef STYLUS_CONTROLLER_HPP
#define STYLUS_CONTROLLER_HPP

#include "controller.hpp"
#include "app/app2d.hpp"

#include "boost/scoped_ptr.hpp"
using namespace boost;

class StylusObserver;

class StylusController : public Controller {
public:
	StylusController(Keycode fire1, Keycode fire2, Keycode suicide,
					 App2D &app, int dheight);
	virtual ~StylusController();

	virtual void get(MapDirection &dir, bool &centred, bool &fire_held,
					 bool &suicide_held) const;

private:
	friend class StylusObserver;
	scoped_ptr<StylusObserver> obs;
	App2D &app;
	int display_height;
	Keycode fire_key_1, fire_key_2, suicide_key;
	bool fire1, fire2, mousedown, suicide;
	int mx, my;
};

#endif
